Fix paths for build bot
diff --git a/PC/VS7.1/build_ssl.py b/PC/VS7.1/build_ssl.py
index 96809b3..2e9f4e3 100644
--- a/PC/VS7.1/build_ssl.py
+++ b/PC/VS7.1/build_ssl.py
@@ -131,7 +131,7 @@
     print "Found a working perl at '%s'" % (perl,)
     sys.stdout.flush()
     # Look for SSL 2 levels up from pcbuild - ie, same place zlib etc all live.
-    ssl_dir = find_best_ssl_dir(("..\\..",))
+    ssl_dir = find_best_ssl_dir(("..\\..\\..",))
     if ssl_dir is None:
         sys.exit(1)
 
diff --git a/PC/VS7.1/rt.bat b/PC/VS7.1/rt.bat
index 8e386c5..29801d2 100755
--- a/PC/VS7.1/rt.bat
+++ b/PC/VS7.1/rt.bat
@@ -10,11 +10,11 @@
 rem whatever remains is passed to regrtest.py.  For example,
 rem     rt -O -d -x test_thread
 rem runs
-rem     python_d -O ../lib/test/regrtest.py -x test_thread
+rem     python_d -O ../../lib/test/regrtest.py -x test_thread
 rem twice, and
 rem     rt -q -g test_binascii
 rem runs
-rem     python_d ../lib/test/regrtest.py -g test_binascii
+rem     python_d ../../lib/test/regrtest.py -g test_binascii
 rem to generate the expected-output file for binascii quickly.
 rem
 rem Confusing:  if you want to pass a comma-separated list, like
@@ -27,14 +27,14 @@
 set exe=python
 set qmode=
 set dashO=
-PATH %PATH%;..\..\tcltk\bin
+PATH %PATH%;..\..\..\tcltk\bin
 
 :CheckOpts
 if "%1"=="-O" (set dashO=-O)     & shift & goto CheckOpts
 if "%1"=="-q" (set qmode=yes)    & shift & goto CheckOpts
 if "%1"=="-d" (set exe=python_d) & shift & goto CheckOpts
 
-set cmd=%exe% %dashO% -E -tt ../lib/test/regrtest.py %1 %2 %3 %4 %5 %6 %7 %8 %9
+set cmd=%exe% %dashO% -E -tt ../../lib/test/regrtest.py %1 %2 %3 %4 %5 %6 %7 %8 %9
 if defined qmode goto Qmode
 
 echo Deleting .pyc/.pyo files ...
diff --git a/Tools/buildbot/build-amd64.bat b/Tools/buildbot/build-amd64.bat
index 88edd8d..cddd3dd 100644
--- a/Tools/buildbot/build-amd64.bat
+++ b/Tools/buildbot/build-amd64.bat
@@ -3,4 +3,4 @@
 cmd /c Tools\buildbot\external-amd64.bat
 call "%VS71COMNTOOLS%vsvars32.bat"
 REM cmd /q/c Tools\buildbot\kill_python.bat
-devenv.com /build ReleaseAMD64 PCbuild\pcbuild.sln
+devenv.com /build ReleaseAMD64 PC\VS7.1\pcbuild.sln
diff --git a/Tools/buildbot/build.bat b/Tools/buildbot/build.bat
index e96323c..f64c219 100644
--- a/Tools/buildbot/build.bat
+++ b/Tools/buildbot/build.bat
@@ -2,4 +2,4 @@
 cmd /c Tools\buildbot\external.bat
 call "%VS71COMNTOOLS%vsvars32.bat"
 cmd /q/c Tools\buildbot\kill_python.bat
-devenv.com /useenv /build Debug PCbuild\pcbuild.sln
+devenv.com /useenv /build Debug PC\VS7.1\pcbuild.sln
diff --git a/Tools/buildbot/buildmsi.bat b/Tools/buildbot/buildmsi.bat
index 8adea48..c30faee 100644
--- a/Tools/buildbot/buildmsi.bat
+++ b/Tools/buildbot/buildmsi.bat
@@ -9,7 +9,7 @@
 
 @rem build Python
 cmd /q/c Tools\buildbot\kill_python.bat
-devenv.com /useenv /build Release PCbuild\pcbuild.sln
+devenv.com /useenv /build Release PC\VS7.1\pcbuild.sln
 
 @rem build the documentation
 bash.exe -c 'cd Doc;make PYTHON=python2.5 update htmlhelp'
diff --git a/Tools/buildbot/clean-amd64.bat b/Tools/buildbot/clean-amd64.bat
index 7ef5e02..e828c88 100644
--- a/Tools/buildbot/clean-amd64.bat
+++ b/Tools/buildbot/clean-amd64.bat
@@ -1,6 +1,6 @@
 @rem Used by the buildbot "clean" step.
 call "%VS71COMNTOOLS%vsvars32.bat"
-cd PCbuild
+cd PC\VS7.1
 @echo Deleting .pyc/.pyo files ...
 python.exe rmpyc.py
 devenv.com /clean ReleaseAMD64 pcbuild.sln
diff --git a/Tools/buildbot/clean.bat b/Tools/buildbot/clean.bat
index 19400a9..5e7e790 100644
--- a/Tools/buildbot/clean.bat
+++ b/Tools/buildbot/clean.bat
@@ -1,6 +1,6 @@
 @rem Used by the buildbot "clean" step.
 call "%VS71COMNTOOLS%vsvars32.bat"
-cd PCbuild
+cd PC\VS7.1
 @echo Deleting .pyc/.pyo files ...
 python_d.exe rmpyc.py
 devenv.com /clean Release pcbuild.sln
diff --git a/Tools/buildbot/test-amd64.bat b/Tools/buildbot/test-amd64.bat
index 6995ece..9cb6968 100644
--- a/Tools/buildbot/test-amd64.bat
+++ b/Tools/buildbot/test-amd64.bat
@@ -1,3 +1,3 @@
 @rem Used by the buildbot "test" step.
-cd PCbuild
+cd PC\VS7.1
 call rt.bat -q -uall -rw
diff --git a/Tools/buildbot/test.bat b/Tools/buildbot/test.bat
index c8b1937..ea4e8d5 100644
--- a/Tools/buildbot/test.bat
+++ b/Tools/buildbot/test.bat
@@ -1,3 +1,3 @@
 @rem Used by the buildbot "test" step.
-cd PCbuild
+cd PC\VS7.1
 call rt.bat -d -q -uall -rw
diff --git a/Tools/buildbot/kill_python.c b/Tools/buildbot/kill_python.c
index 023ff2d..fd707da 100644
--- a/Tools/buildbot/kill_python.c
+++ b/Tools/buildbot/kill_python.c
@@ -1,4 +1,4 @@
 /* This program looks for processes which have build\PCbuild\python.exe
    in their path and terminates them. */
 #include <windows.h>
 #include <psapi.h>
@@ -46,14 +46,14 @@
 		/* Check if we are running a buildbot version of Python.
 
 		   On Windows, this will always be a debug build from the
-		   PCbuild directory.  build\\PCbuild\\python_d.exe
+		   PC\VS7.1 directory.  build\\PC\\VS7.1\\python_d.exe
 		   
 		   On Cygwin, the pathname is similar to other Unixes.
 		   Use \\build\\python.exe to ensure we don't match
-		   PCbuild\\python.exe which could be a normal instance
+		   PC\\VS7.1\\python.exe which could be a normal instance
 		   of Python running on vanilla Windows.
 		*/
-		if ((strstr(path, "build\\pcbuild\\python_d.exe") != NULL) ||
+		if ((strstr(path, "build\\pc\\vs7.1\\python_d.exe") != NULL) ||
 		    (strstr(path, "\\build\\python.exe") != NULL)) {
 			printf("Terminating %s (pid %d)\n", path, pids[i]);
 			if (!TerminateProcess(hProcess, 1)) {
@@ -1,4 +1,4 @@
-/* This program looks for processes which have build\PCbuild\python.exe
+/* This program looks for processes which have build\PC\VS7.1\python.exe
    in their path and terminates them. */
 #include <windows.h>